==> xSocket-0.9-beta-1-sources.jar: org/xsocket/server/MultithreadedSSLServer.java <==
// $Id: MultithreadedServer.java 69 2006-06-22 20:41:42Z grro $
/*
 *  Copyright (c) xsocket.org, 2006. All rights reserved.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Please refer to the LGPL license at: http://www.gnu.org/copyleft/lesser.txt
 * The latest copy of this software may be found on http://www.xsocket.org/
 */

package org.xsocket.server;


import java.io.IOException;
import java.net.UnknownHostException;
import java.nio.channels.SocketChannel;
import java.util.logging.Logger;


/**
 * Implementation of the <code>IMultithreadedServer</code>, which supports ssl
 * 
 * @author grro@xsocket.org
 */
public final class MultithreadedSSLServer extends MultithreadedServer {
	
	private static final Logger LOG = Logger.getLogger(MultithreadedSSLServer.class.getName());
	
	private ISSLContextFactory sslContextFactory = null;
	
		
	/**
	 * constructor
	 * 
	 * @param port the server port
	 * @param domain the domain
	 * @param sslContextFactory the ssl factory to use
	 * @throws UnknownHostException if the locale host cannot determined 
	 */
	public MultithreadedSSLServer(int port, String domain, ISSLContextFactory sslContextFactory) throws UnknownHostException {
		super(port, domain); 
		
		this.sslContextFactory = sslContextFactory;
		
		LOG.fine("usage ssl connection");
	}

	/**
	 * @see MultithreadedServer
	 */
	@Override
	protected NonBlockingConnection newNonBlockingConnection(SocketChannel sc, String id) throws IOException {
		return new NonBlockingSSLConnection(sc, id, sslContextFactory.getSSLContext());
	}
}

==> xSocket-1.0-beta-1-sources.jar: org/xsocket/server/MultithreadedSSLServer.java <==
// $Id: MultithreadedSSLServer.java 69 2006-06-22 20:41:42Z grro $
/*
 *  Copyright (c) xsocket.org, 2006. All rights reserved.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Please refer to the LGPL license at: http://www.gnu.org/copyleft/lesser.txt
 * The latest copy of this software may be found on http://www.xsocket.org/
 */

package org.xsocket.server;


import java.io.IOException;
import java.net.UnknownHostException;
import java.nio.channels.SocketChannel;
import java.util.logging.Logger;


/**
 * Implementation of the <code>IMultithreadedServer</code>, which supports ssl
 * 
 * @author grro@xsocket.org
 */
public final class MultithreadedSSLServer extends MultithreadedServer {
	
	private static final Logger LOG = Logger.getLogger(MultithreadedSSLServer.class.getName());
	
	private ISSLContextFactory sslContextFactory = null;

	
	/** 
	 * constructor
	 * 
	 * @param port the server port
	 * @param sslContextFactory the ssl factory to use
	 * @throws UnknownHostException if the locale host cannot determined 
	 */
	public MultithreadedSSLServer(int port, ISSLContextFactory sslContextFactory) throws UnknownHostException, IOException {
		this(port, "xsocket", sslContextFactory);
	}
		
	/**
	 * constructor
	 * 
	 * @param port the server port
	 * @param domain the domain
	 * @param sslContextFactory the ssl factory to use
	 * @throws UnknownHostException if the locale host cannot determined 
	 */
	public MultithreadedSSLServer(int port, String domain, ISSLContextFactory sslContextFactory) throws UnknownHostException, IOException {
		super(port, domain); 
		
		this.sslContextFactory = sslContextFactory;
		
		LOG.fine("usage ssl connection");
	}

	/**
	 * @see MultithreadedServer
	 */
	@Override
	protected NonBlockingConnection newNonBlockingConnection(SocketChannel sc, String id) throws IOException {
		return new NonBlockingSSLConnection(sc, id, sslContextFactory.getSSLContext());
	}
}
